==> ilias-3.9.6.tbz: www/ilias/Modules/Chat/classes/class.ilChatInvitations.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2001 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/

/**
* Class ilChatInvitations
* 
* @author Sascha Hofmann 
* @version $Id$
*
*/

class ilChatInvitations
{
	/**
	* Constructor
	*/
	function ilChatInvitations()
	{
		return;
	}
	
	function _countNewInvitations($a_user_id)
	{
		global $ilDB, $ilias;

		if (!$a_user_id)
		{
			return 0;
		}

		$q = "SELECT count(*) as invitations FROM chat_invitations WHERE guest_id = ".$ilDB->quote($a_user_id)." ".
			 "AND guest_informed = 0 ".
			 "AND invitation_time > ".(time() - 2 * 60 * 60)." ";
		$row = $ilias->db->getRow($q,DB_FETCHMODE_OBJECT);
		
		return $row->invitations;
	}
} // END class.ilChatInvitations
?>

==> ilias-4.1.4.tbz: www/ilias/Modules/Chat/classes/class.ilChatInvitations.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2009 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/

/**
* Class ilChatInvitations
* 
* @author Sascha Hofmann 
* @version $Id$
*
*/

class ilChatInvitations
{
	/**
	* Constructor
	*/
	function ilChatInvitations()
	{
		return;
	}
	
	public static function _countNewInvitations($a_user_id)
	{
		global $ilDB, $ilias;

		if (!$a_user_id)
		{
			return 0;
		}

		$res = $ilDB->queryf('
			SELECT COUNT(*) invitations FROM chat_invitations
			WHERE guest_id = %s
			AND guest_informed = %s
			AND invitation_time > %s',
			array('integer', 'integer', 'integer'),
			array($a_user_id, '0', time() - 2 * 60 * 60));
		
		$row = $res->fetchRow(DB_FETCHMODE_OBJECT);
		
		return $row->invitations;
	}
	
	public static function _getNewInvitations($a_user_id)
	{
		global $ilDB, $ilias;

		if(!(int)$a_user_id)
		{
			return array();
		}

		$res = $ilDB->queryf('
			SELECT * FROM chat_invitations
			WHERE guest_id = %s
			AND guest_informed = %s
			AND invitation_time > %s',
			array('integer', 'integer', 'integer'),
			array($a_user_id, '0', time() - 2 * 60 * 60));
		
		$rows = array();
		
		while($row = $res->fetchRow(DB_FETCHMODE_ASSOC))
		{
			$rows[] = $row;
		}
		
		return is_array($rows) ? $rows : array();
	}
} // END class.ilChatInvitations
?>
